Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(80)

Unified Diff: chrome/browser/resources/pdf/pdf.js

Issue 1350073002: PDFs viewed inside a <webview> should navigate the same as PDFs in tabs. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Pass boolean instead of tabId. Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/pdf/pdf.js
diff --git a/chrome/browser/resources/pdf/pdf.js b/chrome/browser/resources/pdf/pdf.js
index f426068f2b07ac167a57d1e288191b44ec29c27d..40f74854ce28b087ada3486a331c892609fd0593 100644
--- a/chrome/browser/resources/pdf/pdf.js
+++ b/chrome/browser/resources/pdf/pdf.js
@@ -41,12 +41,13 @@ function getFilenameFromURL(url) {
/**
* Called when navigation happens in the current tab.
+ * @param {boolean} isInTab Indicates if the PDF viewer is displayed in a tab.
* @param {string} url The url to be opened in the current tab.
*/
-function onNavigateInCurrentTab(url) {
- // Prefer the tabs API because it can navigate from one file:// URL to
- // another.
- if (chrome.tabs)
+function onNavigateInCurrentTab(isInTab, url) {
+ // When the PDFviewer is inside a browser tab, prefer the tabs API because
+ // it can navigate from one file:// URL to another.
+ if (chrome.tabs && isInTab)
chrome.tabs.update({url: url});
else
window.location.href = url;
@@ -257,9 +258,12 @@ function PDFViewer(browserApi) {
// Parse open pdf parameters.
this.paramsParser_ =
new OpenPDFParamsParser(this.getNamedDestination_.bind(this));
+ var isInTab = this.browserApi_.getStreamInfo().tabId != -1;
this.navigator_ = new Navigator(this.browserApi_.getStreamInfo().originalUrl,
this.viewport_, this.paramsParser_,
- onNavigateInCurrentTab, onNavigateInNewTab);
+ onNavigateInCurrentTab.bind(undefined,
+ isInTab),
Dan Beam 2015/09/29 22:38:26 function() { onNavigateInCurrentTab(isInTab); },
Dan Beam 2015/09/29 22:38:58 function(url) { onNavigateInCurrentTab(isInTab, ur
+ onNavigateInNewTab);
this.viewportScroller_ =
new ViewportScroller(this.viewport_, this.plugin_, window);
« no previous file with comments | « chrome/browser/apps/guest_view/web_view_browsertest.cc ('k') | extensions/browser/guest_view/web_view/web_view_guest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698